import Search from '@/components/search'
import { View } from '@tarojs/components'
import Taro, { useDidShow } from '@tarojs/taro'
import React, { FC, useCallback, useContext, useEffect, useMemo, useState } from 'react'
import styles from './index.module.scss'
import classnames from 'classnames'
import IconText from '@/components/iconText'
import InfiniteScroll from '@/components/infiniteScroll'
import ItemList from './components/shoppingCartItem/index'
import BottomBtns from '@/components/BottomBtns'
import { formatPriceDiv } from '@/common/format'
import BottomSettleBar from './components/bottomSettleBar'
import BottomEditBar from './components/bottomEditBar'
import { ShoppingCartListApi } from '@/api/index'
import { dataLoadingStatus } from '@/common/util'

const defaultContext = {
  isManager: false
}

export const ShoppingContext = React.createContext(defaultContext)

export const Shopping: FC = () => {
  //输入了搜索关键字
  const getSearchData = useCallback((e) => {
    // pageNum.current.page = 1
    // setOrderData(() => ({ list: [], total: 0 }))
    // setSearchField((val) => ({ ...val, name: e, size: 10 }))
  }, [])
  // 是否在 管理 状态
  const [isManage, setManage] = useState(false)

  // 管理
  const onStartToManage = () => {
    setManage((isManage) => !isManage)
    ShoppingContext.Consumer
  }

  const [selectedAmount, setSelectedAmount] = useState(0)

  // 结算
  const handleSettleAccount = () => {}
  // 删除
  const handleDelete = () => {}

  const handleSelectAllCheckbox = (isSelectAll: boolean) => {
    console.log('handleSelectAllCheckbox', isSelectAll)
  }

  const [listHeight, setListHeight] = useState('auto')

  const { fetchData, state } = ShoppingCartListApi()

  const [shoppingCartData, setShoppingCartData] = useState<{ list: ShoppingCartData[]; total: number }>({ list: [], total: 0 })

  //数据加载状态
  const statusMore = useMemo(() => {
    return dataLoadingStatus({ list: shoppingCartData.list, total: shoppingCartData.total, status: state.loading })
  }, [shoppingCartData, state])

  useDidShow(() => {
    fetchData()
  })

  useEffect(() => {
    setShoppingCartData({ list: state.data, total: state.data.length })
  }, [state])

  useEffect(() => {
    let query = Taro.createSelectorQuery()
    console.log(query)
    query.select('#shoppingContainer').boundingClientRect()
    query.select('#topBar').boundingClientRect()
    query.select('#bottomBar').boundingClientRect()
    query.exec((res) => {
      const containerHeight = res[0].height
      const topBarHeight = res[1].height
      const bottomBarHeight = res[2].height
      const listHeight = containerHeight - topBarHeight - bottomBarHeight
      console.log('res==>', listHeight)
      setListHeight(listHeight + 'px')
    })
  }, [])

  const [selectedId, setSelectedId] = useState<number>()

  const handleSelectedItem = (item: ShoppingCartData) => {
    setSelectedId(item.purchaser_id)
  }

  return (
    <View className={classnames('flex-col', styles.shopping)} id='shoppingContainer'>
      <View className={styles['shopping--topBar']} id='topBar'>
        <Search placeholder='请输入客户名称' showBtn={false} changeOnSearch={getSearchData} debounceTime={300}>
          <View className={styles.flexBox} onClick={onStartToManage}>
            {isManage ? (
              <IconText iconName='icon-guanlidingdan' text='取消' customClass={styles['icon--manage--cancel']} />
            ) : (
              <IconText iconName='icon-guanlidingdan' text='管理' />
            )}
          </View>
        </Search>
      </View>
      <View className={classnames('flex-item', 'flex-col', styles['shopping--context'])}>
        <View className={classnames(styles.shopping__list__container, 'flex-item')} style={{ height: listHeight }}>
          <ShoppingContext.Provider value={{isManager:false}}>
            <InfiniteScroll statusMore={statusMore}>
              {!!shoppingCartData.list?.length &&
                shoppingCartData.list?.map((item, index) => {
                  return <ItemList itemData={item} key={index} selectedId={selectedId}></ItemList>
                })}
            </InfiniteScroll>
          </ShoppingContext.Provider>
        </View>
        <View id='bottomBar'>
          {isManage ? (
            <BottomEditBar onDelete={handleDelete} onSelectCheckbox={handleSelectAllCheckbox}></BottomEditBar>
          ) : (
            <BottomSettleBar onSettleAccount={handleSettleAccount} amount={selectedAmount}></BottomSettleBar>
          )}
        </View>
      </View>
    </View>
  )
}
export default Shopping
